@@ -1,6 +1,7 @@
 import unittest2 as unittest
 from datetime import datetime, timedelta
 
+from celery import conf
 from celery import states
 from celery.utils import gen_unique_id
 
@@ -42,12 +43,12 @@ class TestModels(unittest.TestCase):
         TaskMeta.objects.filter(task_id=m1.task_id).update(
                 date_done=datetime.now() - timedelta(days=10))
 
-        expired = TaskMeta.objects.get_all_expired()
+        expired = TaskMeta.objects.get_all_expired(conf.TASK_RESULT_EXPIRES)
         self.assertIn(m1, expired)
         self.assertNotIn(m2, expired)
         self.assertNotIn(m3, expired)
 
-        TaskMeta.objects.delete_expired()
+        TaskMeta.objects.delete_expired(conf.TASK_RESULT_EXPIRES)
         self.assertNotIn(m1, TaskMeta.objects.all())
 
     def test_tasksetmeta(self):
@@ -66,10 +67,11 @@ class TestModels(unittest.TestCase):
         TaskSetMeta.objects.filter(taskset_id=m1.taskset_id).update(
                 date_done=datetime.now() - timedelta(days=10))
 
-        expired = TaskSetMeta.objects.get_all_expired()
+        expired = TaskSetMeta.objects.get_all_expired(
+                    conf.TASK_RESULT_EXPIRES)
         self.assertIn(m1, expired)
         self.assertNotIn(m2, expired)
         self.assertNotIn(m3, expired)
 
-        TaskSetMeta.objects.delete_expired()
+        TaskSetMeta.objects.delete_expired(conf.TASK_RESULT_EXPIRES)
         self.assertNotIn(m1, TaskSetMeta.objects.all())
